============
Installation
============

At the command line::

    $ easy_install grandcentral

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv grandcentral
    $ pip install grandcentral
